@@ -20,8 +20,42 @@
 #include "cheese-config.h"
 
 #include <glib/gi18n.h>
+#include "cheese-camera-device.h"
+#include "cheese-camera-device-monitor.h"
+#include "cheese-effect.h"
 #include "cheese-fileutil.h"
 
+/* Test CheeseCameraDeviceMonitor */
+static void
+cameradevicemonitor_create (void)
+{
+    CheeseCameraDeviceMonitor *monitor;
+
+    monitor = cheese_camera_device_monitor_new ();
+    g_assert (monitor != NULL);
+
+    cheese_camera_device_monitor_coldplug (monitor);
+
+    g_object_unref (monitor);
+}
+
+/* Test CheeseEffect */
+static void
+effect_create (void)
+{
+    CheeseEffect *effect;
+    static const gchar name[] = "No effect";
+    static const gchar desc[] = "identity";
+
+    effect = cheese_effect_new (name, desc);
+    g_assert (effect != NULL);
+
+    g_assert_cmpstr (name, ==, cheese_effect_get_name (effect));
+    g_assert_cmpstr (desc, ==, cheese_effect_get_pipeline_desc (effect));
+
+    g_object_unref (effect);
+}
+
 /* Test CheeseFileUtil */
 static void
 fileutil_burst (void)
@@ -88,6 +122,36 @@ fileutil_reset_burst (void)
     g_object_unref (fileutil);
 }
 
+static void
+fileutil_new_media_filename (void)
+{
+    CheeseFileUtil *fileutil;
+    const gchar *filename;
+
+    fileutil = cheese_fileutil_new ();
+    g_assert (fileutil != NULL);
+
+    filename = cheese_fileutil_get_new_media_filename (fileutil,
+        CHEESE_MEDIA_MODE_PHOTO);
+    g_assert (filename != NULL);
+    g_assert (g_str_has_suffix (filename, CHEESE_PHOTO_NAME_SUFFIX));
+    g_assert (!g_file_test (filename, G_FILE_TEST_EXISTS));
+
+    filename = cheese_fileutil_get_new_media_filename (fileutil,
+        CHEESE_MEDIA_MODE_BURST);
+    g_assert (filename != NULL);
+    g_assert (g_str_has_suffix (filename, CHEESE_PHOTO_NAME_SUFFIX));
+    g_assert (!g_file_test (filename, G_FILE_TEST_EXISTS));
+
+    filename = cheese_fileutil_get_new_media_filename (fileutil,
+        CHEESE_MEDIA_MODE_VIDEO);
+    g_assert (filename != NULL);
+    g_assert (g_str_has_suffix (filename, CHEESE_VIDEO_NAME_SUFFIX));
+    g_assert (!g_file_test (filename, G_FILE_TEST_EXISTS));
+
+    g_object_unref (fileutil);
+}
+
 static void
 fileutil_photo_path (void)
 {
@@ -122,20 +186,47 @@ fileutil_video_path (void)
     g_object_unref (fileutil);
 }
 
-int main (int argc, gchar *argv[])
+/* Test CheeseVideoFormat (part of CheeseCameraDevice) */
+static void
+videoformat_create (void)
+{
+    CheeseVideoFormat *other;
+    CheeseVideoFormat format = { 640, 480 };
+
+    other = g_boxed_copy (CHEESE_TYPE_VIDEO_FORMAT, &format);
+    g_assert (other != NULL);
+    g_assert_cmpint (other->width, ==, format.width);
+    g_assert_cmpint (other->height, ==, format.height);
+
+    g_boxed_free (CHEESE_TYPE_VIDEO_FORMAT, other);
+}
+
+int
+main(int argc, gchar *argv[])
 {
     g_thread_init (NULL);
     g_type_init ();
 
     g_test_init (&argc, &argv, NULL);
 
+    gst_init (&argc, &argv);
+
+    g_test_add_func ("/libcheese/cameradevicemonitor/create",
+        cameradevicemonitor_create);
+
+    g_test_add_func ("/libcheese/effect/create", effect_create);
+
     if (g_test_slow ())
     {
         g_test_add_func ("/libcheese/fileutil/burst", fileutil_burst);
         g_test_add_func ("/libcheese/fileutil/reset_burst", fileutil_reset_burst);
     }
+    g_test_add_func ("/libcheese/fileutil/new_media_filename",
+        fileutil_new_media_filename);
     g_test_add_func ("/libcheese/fileutil/photo_path", fileutil_photo_path);
     g_test_add_func ("/libcheese/fileutil/video_path", fileutil_video_path);
 
+    g_test_add_func ("/libcheese/videoformat/create", videoformat_create);
+
     return g_test_run ();
 }
